# allianceauth-app-utils

[![release](https://img.shields.io/pypi/v/allianceauth-app-utils?label=release)](https://pypi.org/project/allianceauth-app-utils/)
[![python](https://img.shields.io/pypi/pyversions/allianceauth-app-utils)](https://pypi.org/project/allianceauth-app-utils/)
[![django](https://img.shields.io/pypi/djversions/allianceauth-app-utils?label=django)](https://pypi.org/project/allianceauth-app-utils/)
[![pipeline](https://gitlab.com/ErikKalkoken/allianceauth-app-utils/badges/master/pipeline.svg)](https://gitlab.com/ErikKalkoken/allianceauth-app-utils/-/pipelines)
[![codecov](https://codecov.io/gl/ErikKalkoken/allianceauth-app-utils/branch/master/graph/badge.svg?token=S6AUWTRHC4)](https://codecov.io/gl/ErikKalkoken/allianceauth-app-utils)
[![Documentation Status](https://readthedocs.org/projects/allianceauth-app-utils/badge/?version=latest)](https://allianceauth-app-utils.readthedocs.io/en/latest/?badge=latest)
[![license](https://img.shields.io/badge/license-MIT-green)](https://gitlab.com/ErikKalkoken/allianceauth-app-utils/-/blob/master/LICENSE)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![chat](https://img.shields.io/discord/790364535294132234)](https://discord.gg/zmh52wnfvM)

Commonly used utility functions and classes for rapid development of Alliance Auth apps.

## Description

This package contains a variety of commonly used utility functions and classes that help speed up development of Alliance Auth apps and reduce code duplication across apps.

## Documentation

For a full description of the API please see the [documentation](https://allianceauth-app-utils.readthedocs.io/en/latest/index.html).
